@@ -1,7 +1,7 @@
 package App::GitUtils;
 
-our $DATE = '2014-08-28'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-03-21'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -12,6 +12,11 @@ use File::chdir;
 
 our %SPEC;
 
+$SPEC{':package'} = {
+    v => 1.1,
+    summary => 'Day-to-day command-line utilities for git',
+};
+
 our $_complete_hook = sub {
     my %args = @_;
 
@@ -163,19 +168,21 @@ App::GitUtils - Day-to-day command-line utilities for git
 
 =head1 VERSION
 
-This document describes version 0.04 of App::GitUtils (from Perl distribution App-GitUtils), released on 2014-08-28.
+This document describes version 0.05 of App::GitUtils (from Perl distribution App-GitUtils), released on 2015-03-21.
 
 =head1 SYNOPSIS
 
 This distribution provides the following command-line utilities:
 
- gu
+=over
+
+=item * L<gu>
+
+=back
 
 These utilities provide some shortcuts and tab completion to make it more
 convenient when working with git con the command-line.
 
-More utilities will be added in the future.
-
 =head1 FUNCTIONS
 
 
@@ -185,8 +192,6 @@ Return information about git repository.
 
 No arguments.
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -196,7 +201,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 list_hooks() -> [status, msg, result, meta]
@@ -205,8 +210,6 @@ List available hooks for the repository.
 
 No arguments.
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -216,7 +219,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 post_commit() -> [status, msg, result, meta]
@@ -231,8 +234,6 @@ except can be done anywhere inside git repo.
 
 No arguments.
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -242,7 +243,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 pre_commit() -> [status, msg, result, meta]
@@ -257,8 +258,6 @@ except can be done anywhere inside git repo.
 
 No arguments.
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -268,7 +267,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 run_hook(%args) -> [status, msg, result, meta]
@@ -277,7 +276,7 @@ Run a hook.
 
 Basically the same as:
 
- % .git/hooks/E<lt>hook-nameE<gt>
+ % .git/hooks/<hook-name>
 
 except can be done anywhere inside git repo and provides tab completion.
 
@@ -291,8 +290,6 @@ Hook name, e.g. post-commit.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -302,10 +299,46 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
+
+=head1 FAQ
+
+=head2 What is the purpose of this distribution? Haven't other similar utilities existed?
+
+For example, L<mpath> from L<Module::Path> distribution is similar to L<pmpath>
+in L<App::PMUtils>, and L<mversion> from L<Module::Version> distribution is
+similar to L<pmversion> from L<App::PMUtils> distribution, and so on.
+
+True. The main point of these utilities is shell tab completion, to save
+typing.
 
 =head1 SEE ALSO
 
+Below is the list of distributions that provide CLI utilities for various
+purposes, with the focus on providing shell tab completion feature.
+
+L<App::DistUtils>, utilities related to Perl distributions.
+
+L<App::DzilUtils>, utilities related to L<Dist::Zilla>.
+
+L<App::GitUtils>, utilities related to git.
+
+L<App::IODUtils>, utilities related to L<IOD> configuration files.
+
+L<App::LedgerUtils>, utilities related to Ledger CLI files.
+
+L<App::OrgUtils>, utilities related to Org files.
+
+L<App::PlUtils>, utilities related to Perl scripts.
+
+L<App::PMUtils>, utilities related to Perl modules.
+
+L<App::ProgUtils>, utilities related to programs.
+
+L<App::UpfUtils>, utilities related to Unix password/shadow files.
+
+L<App::WeaverUtils>, utilities related to L<Pod::Weaver>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-GitUtils>.
@@ -328,7 +361,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
